@@ -2,8 +2,7 @@
 # Syntext: a lightweight, markdownish markup language.
 # ---------------------------------------------------------
 
-# Package version number.
-__version__ = "2.10.0"
+__version__ = "3.1.1"
 
 from .interface import render
 from .interface import main
@@ -12,6 +11,5 @@ from .utils import SyntextError
 from . import tags
 from . import nodes
 from . import parsers
-from . import escapes
 from . import utils
 from . import shorthand
